==> ZenTaoALM.12.4.1.int.zbox_32.tar.gz: zbox/app/zentaoep/tmp/defaultvalue/bizext.php <==
<?php
$paramDefaultValue['api']['mobilecomment']['content'] = '';
$paramDefaultValue['api']['mobilecomment']['user'] = '';
$paramDefaultValue['api']['mobilegetcustom']['module'] = 'common';
$paramDefaultValue['api']['mobilegetcustom']['lang'] = 'zh_cn';
$paramDefaultValue['api']['mobilegetinfo']['history'] = 0;
$paramDefaultValue['api']['mobilegetlist']['type'] = 'full';
$paramDefaultValue['api']['mobilegetlist']['object'] = 'all';
$paramDefaultValue['api']['mobilegetlist']['range'] = 0;
$paramDefaultValue['api']['mobilegetlist']['last'] = '';
$paramDefaultValue['api']['mobilegetlist']['records'] = 1000;
$paramDefaultValue['api']['mobilegetlist']['format'] = 'index';
$paramDefaultValue['mybug']['export']['browseType'] = '';
$paramDefaultValue['mybug']['exporttemplet']['branch'] = 0;
$paramDefaultValue['mybug']['import']['branch'] = 0;
$paramDefaultValue['mybug']['showimport']['branch'] = 0;
$paramDefaultValue['mybug']['showimport']['pagerID'] = 1;
$paramDefaultValue['mybug']['showimport']['maxImport'] = 0;
$paramDefaultValue['mybug']['showimport']['insert'] = '';
$paramDefaultValue['mycaselib']['showimport']['pagerID'] = 1;
$paramDefaultValue['mycaselib']['showimport']['maxImport'] = 0;
$paramDefaultValue['mycaselib']['showimport']['insert'] = '';
$paramDefaultValue['company']['calendar']['parent'] = 0;
$paramDefaultValue['company']['calendar']['begin'] = 0;
$paramDefaultValue['company']['calendar']['end'] = 0;
$paramDefaultValue['company']['calendar']['product'] = 0;
$paramDefaultValue['company']['calendar']['project'] = 0;
$paramDefaultValue['company']['calendar']['user'] = '';
$paramDefaultValue['company']['calendar']['showAll'] = 0;
$paramDefaultValue['company']['calendar']['iframe'] = 'no';
$paramDefaultValue['company']['effort']['date'] = 'today';
$paramDefaultValue['company']['effort']['orderBy'] = 'date_desc';
$paramDefaultValue['company']['effort']['recTotal'] = 0;
$paramDefaultValue['company']['effort']['recPerPage'] = 20;
$paramDefaultValue['company']['effort']['pageID'] = 1;
$paramDefaultValue['company']['todo']['parent'] = 0;
$paramDefaultValue['company']['todo']['begin'] = 0;
$paramDefaultValue['company']['todo']['end'] = 0;
$paramDefaultValue['company']['todo']['iframe'] = 'no';
$paramDefaultValue['effort']['batchcreate']['date'] = 'today';
$paramDefaultValue['effort']['batchcreate']['account'] = '';
$paramDefaultValue['effort']['createforobject']['account'] = '';
$paramDefaultValue['effort']['createforobject']['date'] = '';
$paramDefaultValue['effort']['batchedit']['from'] = 'browse';
$paramDefaultValue['effort']['batchedit']['account'] = '';
$paramDefaultValue['effort']['view']['from'] = 'company';
$paramDefaultValue['effort']['delete']['confirm'] = 'no';
$paramDefaultValue['effort']['export']['orderBy'] = 'id_desc';
$paramDefaultValue['effort']['ajaxgetefforts']['account'] = '';
$paramDefaultValue['effort']['ajaxgetefforts']['year'] = '';
$paramDefaultValue['myeffort']['batchcreate']['date'] = 'today';
$paramDefaultValue['myeffort']['batchcreate']['account'] = '';
$paramDefaultValue['effort']['calendar']['account'] = '';
$paramDefaultValue['myeffort']['export']['orderBy'] = 'id_desc';
$paramDefaultValue['myeffort']['export']['date'] = '';
$paramDefaultValue['myeffort']['export']['projectID'] = 0;
$paramDefaultValue['my']['effort']['type'] = 'all';
$paramDefaultValue['my']['effort']['orderBy'] = 'date_desc';
$paramDefaultValue['my']['effort']['recTotal'] = 0;
$paramDefaultValue['my']['effort']['recPerPage'] = 20;
$paramDefaultValue['my']['effort']['pageID'] = 1;
$paramDefaultValue['mymy']['requirement']['type'] = 'assignedTo';
$paramDefaultValue['mymy']['requirement']['orderBy'] = 'id_desc';
$paramDefaultValue['mymy']['requirement']['recTotal'] = 0;
$paramDefaultValue['mymy']['requirement']['recPerPage'] = 20;
$paramDefaultValue['mymy']['requirement']['pageID'] = 1;
$paramDefaultValue['project']['ajaxgetefforts']['account'] = '';
$paramDefaultValue['project']['ajaxgetefforts']['year'] = '';
$paramDefaultValue['myproject']['computetaskeffort']['reload'] = 'no';
$paramDefaultValue['project']['deleterelation']['confirm'] = 'no';
$paramDefaultValue['myproject']['effort']['date'] = 'today';
$paramDefaultValue['myproject']['effort']['account'] = '';
$paramDefaultValue['myproject']['effort']['orderBy'] = 'date_desc';
$paramDefaultValue['myproject']['effort']['recTotal'] = 0;
$paramDefaultValue['myproject']['effort']['recPerPage'] = 20;
$paramDefaultValue['myproject']['effort']['pageID'] = 1;
$paramDefaultValue['myproject']['effortcalendar']['account'] = '';
$paramDefaultValue['myproject']['gantt']['type'] = '';
$paramDefaultValue['myproject']['maintainrelation']['projectID'] = 0;
$paramDefaultValue['myproject']['relation']['projectID'] = 0;
$paramDefaultValue['myproject']['taskeffort']['groupBy'] = 'story';
$paramDefaultValue['myproject']['taskeffort']['type'] = 'noweekend';
$paramDefaultValue['myrepo']['ajaxgetprojects']['branch'] = 0;
$paramDefaultValue['myrepo']['deletebug']['confirm'] = 'no';
$paramDefaultValue['myrepo']['deletecomment']['confirm'] = 'no';
$paramDefaultValue['myrepo']['review']['browseType'] = 'all';
$paramDefaultValue['myrepo']['review']['orderBy'] = 'id_desc';
$paramDefaultValue['myrepo']['review']['recTotal'] = 0;
$paramDefaultValue['myrepo']['review']['recPerPage'] = 20;
$paramDefaultValue['myrepo']['review']['pageID'] = 1;
$paramDefaultValue['report']['ajaxcheckvar']['reportID'] = 0;
$paramDefaultValue['report']['ajaxcheckvar']['type'] = '';
$paramDefaultValue['report']['ajaxsetlang']['reportID'] = 0;
$paramDefaultValue['report']['browsereport']['module'] = '';
$paramDefaultValue['report']['browsereport']['orderBy'] = 'id_desc';
$paramDefaultValue['report']['browsereport']['recTotal'] = 0;
$paramDefaultValue['report']['browsereport']['recPerPage'] = 20;
$paramDefaultValue['report']['browsereport']['pageID'] = 1;
$paramDefaultValue['report']['bugassignsummary']['dept'] = 0;
$paramDefaultValue['report']['bugassignsummary']['begin'] = 0;
$paramDefaultValue['report']['bugassignsummary']['end'] = 0;
$paramDefaultValue['report']['bugsummary']['dept'] = 0;
$paramDefaultValue['report']['bugsummary']['begin'] = 0;
$paramDefaultValue['report']['bugsummary']['end'] = 0;
$paramDefaultValue['report']['build']['productID'] = 0;
$paramDefaultValue['report']['casesrun']['productID'] = 0;
$paramDefaultValue['report']['crystalexport']['step'] = 2;
$paramDefaultValue['report']['crystalexport']['reportID'] = 0;
$paramDefaultValue['report']['custom']['step'] = 0;
$paramDefaultValue['report']['custom']['reportID'] = 0;
$paramDefaultValue['report']['custom']['type'] = '';
$paramDefaultValue['report']['deletereport']['reportID'] = 0;
$paramDefaultValue['report']['deletereport']['confirm'] = 'no';
$paramDefaultValue['report']['editreport']['reportID'] = 0;
$paramDefaultValue['report']['export']['productID'] = 0;
$paramDefaultValue['report']['export']['taskID'] = 0;
$paramDefaultValue['report']['reportexport']['params'] = '';
$paramDefaultValue['report']['roadmap']['conditions'] = '';
$paramDefaultValue['report']['savereport']['reportID'] = 0;
$paramDefaultValue['report']['savereport']['step'] = 2;
$paramDefaultValue['report']['savereport']['type'] = '';
$paramDefaultValue['report']['show']['reportModule'] = '';
$paramDefaultValue['report']['storylinkedbug']['productID'] = 0;
$paramDefaultValue['report']['storylinkedbug']['moduleID'] = 0;
$paramDefaultValue['report']['testcase']['productID'] = 0;
$paramDefaultValue['report']['usereport']['reportID'] = 0;
$paramDefaultValue['report']['workassignsummary']['begin'] = 0;
$paramDefaultValue['report']['workassignsummary']['end'] = 0;
$paramDefaultValue['report']['workassignsummary']['dept'] = 0;
$paramDefaultValue['report']['worksummary']['begin'] = 0;
$paramDefaultValue['report']['worksummary']['end'] = 0;
$paramDefaultValue['report']['worksummary']['dept'] = 0;
$paramDefaultValue['search']['buildindex']['type'] = '';
$paramDefaultValue['search']['buildindex']['lastID'] = 0;
$paramDefaultValue['search']['index']['recTotal'] = 0;
$paramDefaultValue['search']['index']['pageID'] = 1;
$paramDefaultValue['mystory']['export']['projectID'] = 0;
$paramDefaultValue['mystory']['export']['browseType'] = '';
$paramDefaultValue['mystory']['export']['type'] = 'story';
$paramDefaultValue['mystory']['exporttemplet']['branch'] = 0;
$paramDefaultValue['mystory']['exporttemplet']['type'] = 'story';
$paramDefaultValue['mystory']['import']['branch'] = 0;
$paramDefaultValue['mystory']['import']['type'] = 'story';
$paramDefaultValue['mystory']['showimport']['branch'] = 0;
$paramDefaultValue['mystory']['showimport']['type'] = 'story';
$paramDefaultValue['mystory']['showimport']['pagerID'] = 1;
$paramDefaultValue['mystory']['showimport']['maxImport'] = 0;
$paramDefaultValue['mystory']['showimport']['insert'] = '';
$paramDefaultValue['mytask']['showimport']['pagerID'] = 1;
$paramDefaultValue['mytask']['showimport']['maxImport'] = 0;
$paramDefaultValue['mytask']['showimport']['insert'] = '';
$paramDefaultValue['testcase']['ajaxselectstory']['type'] = 'all';
$paramDefaultValue['testcase']['ajaxselectstory']['queryID'] = 0;
$paramDefaultValue['mytestcase']['export']['taskID'] = 0;
$paramDefaultValue['mytestcase']['export']['browseType'] = '';
$paramDefaultValue['mytestcase']['import']['branch'] = 0;
$paramDefaultValue['mytestcase']['showimport']['branch'] = 0;
$paramDefaultValue['mytestcase']['showimport']['pagerID'] = 1;
$paramDefaultValue['mytestcase']['showimport']['maxImport'] = 0;
$paramDefaultValue['mytestcase']['showimport']['insert'] = '';
$paramDefaultValue['todo']['ajaxgettodos']['account'] = '';
$paramDefaultValue['todo']['ajaxgettodos']['year'] = '';
$paramDefaultValue['mytodo']['batchcreate']['date'] = 'today';
$paramDefaultValue['mytodo']['batchcreate']['account'] = '';
$paramDefaultValue['todo']['calendar']['account'] = '';
$paramDefaultValue['mytodo']['export']['date'] = '';
$paramDefaultValue['myupgrade']['execute']['fromVersion'] = '';
$paramDefaultValue['myuser']['batchcreate']['deptID'] = 0;
$paramDefaultValue['myuser']['create']['deptID'] = 0;
$paramDefaultValue['user']['effort']['account'] = '';
$paramDefaultValue['user']['effort']['type'] = 'today';
$paramDefaultValue['user']['effort']['recTotal'] = 0;
$paramDefaultValue['user']['effort']['recPerPage'] = 20;
$paramDefaultValue['user']['effort']['pageID'] = 1;
$paramDefaultValue['myuser']['importldap']['type'] = 'all';
$paramDefaultValue['myuser']['importldap']['param'] = 0;
$paramDefaultValue['myuser']['importldap']['recTotal'] = 0;
$paramDefaultValue['myuser']['importldap']['recPerPage'] = 20;
$paramDefaultValue['myuser']['importldap']['pageID'] = 1;
$paramDefaultValue['myuser']['login']['referer'] = '';
$paramDefaultValue['myuser']['login']['from'] = '';
$paramDefaultValue['myuser']['login']['type'] = 'ldap';

==> ZenTaoALM.12.5.2.int.zbox_32.tar.gz: zbox/app/zentaoep/tmp/defaultvalue/bizext.php <==
<?php
$paramDefaultValue['api']['mobilecomment']['content'] = '';
$paramDefaultValue['api']['mobilecomment']['user'] = '';
$paramDefaultValue['api']['mobilegetcustom']['module'] = 'common';
$paramDefaultValue['api']['mobilegetcustom']['lang'] = 'zh_cn';
$paramDefaultValue['api']['mobilegetinfo']['history'] = 0;
$paramDefaultValue['api']['mobilegetlist']['type'] = 'full';
$paramDefaultValue['api']['mobilegetlist']['object'] = 'all';
$paramDefaultValue['api']['mobilegetlist']['range'] = 0;
$paramDefaultValue['api']['mobilegetlist']['last'] = '';
$paramDefaultValue['api']['mobilegetlist']['records'] = 1000;
$paramDefaultValue['api']['mobilegetlist']['format'] = 'index';
$paramDefaultValue['mybug']['export']['browseType'] = '';
$paramDefaultValue['mybug']['export']['projectID'] = 0;
$paramDefaultValue['mybug']['exporttemplet']['branch'] = 0;
$paramDefaultValue['mybug']['import']['branch'] = 0;
$paramDefaultValue['mybug']['showimport']['branch'] = 0;
$paramDefaultValue['mybug']['showimport']['pagerID'] = 1;
$paramDefaultValue['mybug']['showimport']['maxImport'] = 0;
$paramDefaultValue['mybug']['showimport']['insert'] = '';
$paramDefaultValue['mycaselib']['showimport']['pagerID'] = 1;
$paramDefaultValue['mycaselib']['showimport']['maxImport'] = 0;
$paramDefaultValue['mycaselib']['showimport']['insert'] = '';
$paramDefaultValue['company']['calendar']['parent'] = 0;
$paramDefaultValue['company']['calendar']['begin'] = 0;
$paramDefaultValue['company']['calendar']['end'] = 0;
$paramDefaultValue['company']['calendar']['product'] = 0;
$paramDefaultValue['company']['calendar']['project'] = 0;
$paramDefaultValue['company']['calendar']['userID'] = '';
$paramDefaultValue['company']['calendar']['showAll'] = 0;
$paramDefaultValue['company']['calendar']['iframe'] = 'no';
$paramDefaultValue['company']['effort']['date'] = 'today';
$paramDefaultValue['company']['effort']['orderBy'] = 'date_desc';
$paramDefaultValue['company']['effort']['recTotal'] = 0;
$paramDefaultValue['company']['effort']['recPerPage'] = 20;
$paramDefaultValue['company']['effort']['pageID'] = 1;
$paramDefaultValue['company']['todo']['parent'] = 0;
$paramDefaultValue['company']['todo']['begin'] = 0;
$paramDefaultValue['company']['todo']['end'] = 0;
$paramDefaultValue['company']['todo']['iframe'] = 'no';
$paramDefaultValue['effort']['batchcreate']['date'] = 'today';
$paramDefaultValue['effort']['batchcreate']['userID'] = '';
$paramDefaultValue['effort']['batchedit']['from'] = 'browse';
$paramDefaultValue['effort']['batchedit']['userID'] = '';
$paramDefaultValue['effort']['view']['from'] = 'company';
$paramDefaultValue['effort']['delete']['confirm'] = 'no';
$paramDefaultValue['effort']['export']['orderBy'] = 'id_desc';
$paramDefaultValue['effort']['ajaxgetefforts']['userID'] = '';
$paramDefaultValue['effort']['ajaxgetefforts']['year'] = '';
$paramDefaultValue['myeffort']['batchcreate']['date'] = 'today';
$paramDefaultValue['myeffort']['batchcreate']['userID'] = '';
$paramDefaultValue['effort']['calendar']['userID'] = '';
$paramDefaultValue['myeffort']['export']['orderBy'] = 'id_desc';
$paramDefaultValue['myeffort']['export']['date'] = '';
$paramDefaultValue['myeffort']['export']['projectID'] = 0;
$paramDefaultValue['my']['effort']['type'] = 'all';
$paramDefaultValue['my']['effort']['orderBy'] = 'date_desc';
$paramDefaultValue['my']['effort']['recTotal'] = 0;
$paramDefaultValue['my']['effort']['recPerPage'] = 20;
$paramDefaultValue['my']['effort']['pageID'] = 1;
$paramDefaultValue['mymy']['requirement']['type'] = 'assignedTo';
$paramDefaultValue['mymy']['requirement']['orderBy'] = 'id_desc';
$paramDefaultValue['mymy']['requirement']['recTotal'] = 0;
$paramDefaultValue['mymy']['requirement']['recPerPage'] = 20;
$paramDefaultValue['mymy']['requirement']['pageID'] = 1;
$paramDefaultValue['project']['ajaxgetefforts']['userID'] = '';
$paramDefaultValue['project']['ajaxgetefforts']['year'] = '';
$paramDefaultValue['myproject']['computetaskeffort']['reload'] = 'no';
$paramDefaultValue['project']['deleterelation']['confirm'] = 'no';
$paramDefaultValue['myproject']['effort']['date'] = 'today';
$paramDefaultValue['myproject']['effort']['userID'] = '';
$paramDefaultValue['myproject']['effort']['orderBy'] = 'date_desc';
$paramDefaultValue['myproject']['effort']['recTotal'] = 0;
$paramDefaultValue['myproject']['effort']['recPerPage'] = 20;
$paramDefaultValue['myproject']['effort']['pageID'] = 1;
$paramDefaultValue['myproject']['effortcalendar']['userID'] = '';
$paramDefaultValue['myproject']['gantt']['type'] = '';
$paramDefaultValue['myproject']['maintainrelation']['projectID'] = 0;
$paramDefaultValue['myproject']['relation']['projectID'] = 0;
$paramDefaultValue['myproject']['taskeffort']['groupBy'] = 'story';
$paramDefaultValue['myproject']['taskeffort']['type'] = 'noweekend';
$paramDefaultValue['myrepo']['ajaxgetprojects']['branch'] = 0;
$paramDefaultValue['myrepo']['deletebug']['confirm'] = 'no';
$paramDefaultValue['myrepo']['deletecomment']['confirm'] = 'no';
$paramDefaultValue['myrepo']['review']['browseType'] = 'all';
$paramDefaultValue['myrepo']['review']['orderBy'] = 'id_desc';
$paramDefaultValue['myrepo']['review']['recTotal'] = 0;
$paramDefaultValue['myrepo']['review']['recPerPage'] = 20;
$paramDefaultValue['myrepo']['review']['pageID'] = 1;
$paramDefaultValue['report']['ajaxcheckvar']['reportID'] = 0;
$paramDefaultValue['report']['ajaxcheckvar']['type'] = '';
$paramDefaultValue['report']['ajaxsetlang']['reportID'] = 0;
$paramDefaultValue['report']['browsereport']['module'] = '';
$paramDefaultValue['report']['browsereport']['orderBy'] = 'id_desc';
$paramDefaultValue['report']['browsereport']['recTotal'] = 0;
$paramDefaultValue['report']['browsereport']['recPerPage'] = 20;
$paramDefaultValue['report']['browsereport']['pageID'] = 1;
$paramDefaultValue['report']['bugassignsummary']['dept'] = 0;
$paramDefaultValue['report']['bugassignsummary']['begin'] = 0;
$paramDefaultValue['report']['bugassignsummary']['end'] = 0;
$paramDefaultValue['report']['bugsummary']['dept'] = 0;
$paramDefaultValue['report']['bugsummary']['begin'] = 0;
$paramDefaultValue['report']['bugsummary']['end'] = 0;
$paramDefaultValue['report']['build']['productID'] = 0;
$paramDefaultValue['report']['casesrun']['productID'] = 0;
$paramDefaultValue['report']['crystalexport']['step'] = 2;
$paramDefaultValue['report']['crystalexport']['reportID'] = 0;
$paramDefaultValue['report']['custom']['step'] = 0;
$paramDefaultValue['report']['custom']['reportID'] = 0;
$paramDefaultValue['report']['custom']['type'] = '';
$paramDefaultValue['report']['deletereport']['reportID'] = 0;
$paramDefaultValue['report']['deletereport']['confirm'] = 'no';
$paramDefaultValue['report']['editreport']['reportID'] = 0;
$paramDefaultValue['report']['export']['productID'] = 0;
$paramDefaultValue['report']['export']['taskID'] = 0;
$paramDefaultValue['report']['reportexport']['params'] = '';
$paramDefaultValue['report']['roadmap']['conditions'] = '';
$paramDefaultValue['report']['savereport']['reportID'] = 0;
$paramDefaultValue['report']['savereport']['step'] = 2;
$paramDefaultValue['report']['savereport']['type'] = '';
$paramDefaultValue['report']['show']['reportModule'] = '';
$paramDefaultValue['report']['storylinkedbug']['productID'] = 0;
$paramDefaultValue['report']['storylinkedbug']['moduleID'] = 0;
$paramDefaultValue['report']['testcase']['productID'] = 0;
$paramDefaultValue['report']['usereport']['reportID'] = 0;
$paramDefaultValue['report']['workassignsummary']['begin'] = 0;
$paramDefaultValue['report']['workassignsummary']['end'] = 0;
$paramDefaultValue['report']['workassignsummary']['dept'] = 0;
$paramDefaultValue['report']['worksummary']['begin'] = 0;
$paramDefaultValue['report']['worksummary']['end'] = 0;
$paramDefaultValue['report']['worksummary']['dept'] = 0;
$paramDefaultValue['search']['buildindex']['type'] = '';
$paramDefaultValue['search']['buildindex']['lastID'] = 0;
$paramDefaultValue['search']['index']['recTotal'] = 0;
$paramDefaultValue['search']['index']['pageID'] = 1;
$paramDefaultValue['mystory']['export']['projectID'] = 0;
$paramDefaultValue['mystory']['export']['browseType'] = '';
$paramDefaultValue['mystory']['export']['type'] = 'story';
$paramDefaultValue['mystory']['exporttemplet']['branch'] = 0;
$paramDefaultValue['mystory']['exporttemplet']['type'] = 'story';
$paramDefaultValue['mystory']['import']['branch'] = 0;
$paramDefaultValue['mystory']['import']['type'] = 'story';
$paramDefaultValue['mystory']['showimport']['branch'] = 0;
$paramDefaultValue['mystory']['showimport']['type'] = 'story';
$paramDefaultValue['mystory']['showimport']['pagerID'] = 1;
$paramDefaultValue['mystory']['showimport']['maxImport'] = 0;
$paramDefaultValue['mystory']['showimport']['insert'] = '';
$paramDefaultValue['mytask']['showimport']['pagerID'] = 1;
$paramDefaultValue['mytask']['showimport']['maxImport'] = 0;
$paramDefaultValue['mytask']['showimport']['insert'] = '';
$paramDefaultValue['testcase']['ajaxselectstory']['type'] = 'all';
$paramDefaultValue['testcase']['ajaxselectstory']['queryID'] = 0;
$paramDefaultValue['mytestcase']['export']['taskID'] = 0;
$paramDefaultValue['mytestcase']['export']['browseType'] = '';
$paramDefaultValue['mytestcase']['import']['branch'] = 0;
$paramDefaultValue['mytestcase']['showimport']['branch'] = 0;
$paramDefaultValue['mytestcase']['showimport']['pagerID'] = 1;
$paramDefaultValue['mytestcase']['showimport']['maxImport'] = 0;
$paramDefaultValue['mytestcase']['showimport']['insert'] = '';
$paramDefaultValue['todo']['ajaxgettodos']['userID'] = '';
$paramDefaultValue['todo']['ajaxgettodos']['year'] = '';
$paramDefaultValue['mytodo']['batchcreate']['date'] = 'today';
$paramDefaultValue['mytodo']['batchcreate']['userID'] = '';
$paramDefaultValue['todo']['calendar']['userID'] = '';
$paramDefaultValue['mytodo']['export']['date'] = '';
$paramDefaultValue['myupgrade']['execute']['fromVersion'] = '';
$paramDefaultValue['myuser']['batchcreate']['deptID'] = 0;
$paramDefaultValue['myuser']['create']['deptID'] = 0;
$paramDefaultValue['user']['effort']['userID'] = '';
$paramDefaultValue['user']['effort']['type'] = 'today';
$paramDefaultValue['user']['effort']['recTotal'] = 0;
$paramDefaultValue['user']['effort']['recPerPage'] = 20;
$paramDefaultValue['user']['effort']['pageID'] = 1;
$paramDefaultValue['myuser']['importldap']['type'] = 'all';
$paramDefaultValue['myuser']['importldap']['param'] = 0;
$paramDefaultValue['myuser']['importldap']['recTotal'] = 0;
$paramDefaultValue['myuser']['importldap']['recPerPage'] = 20;
$paramDefaultValue['myuser']['importldap']['pageID'] = 1;
$paramDefaultValue['myuser']['login']['referer'] = '';
$paramDefaultValue['myuser']['login']['from'] = '';
$paramDefaultValue['myuser']['login']['type'] = 'ldap';
